package com.example.myapplication

import android.content.ComponentName
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material3.Button
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.DisposableEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.core.net.toUri
import androidx.media3.common.MediaItem
import androidx.media3.common.MediaMetadata
import androidx.media3.datasource.DefaultDataSource
import androidx.media3.datasource.okhttp.OkHttpDataSource
import androidx.media3.exoplayer.ExoPlayer
import androidx.media3.exoplayer.source.DefaultMediaSourceFactory
import androidx.media3.exoplayer.util.EventLogger
import androidx.media3.session.MediaController
import androidx.media3.session.SessionToken
import com.example.myapplication.ui.theme.MyApplicationTheme
import com.google.common.util.concurrent.MoreExecutors
import kotlinx.coroutines.guava.await
import kotlinx.coroutines.launch
import okhttp3.OkHttpClient

class MainActivity : ComponentActivity() {
    private var mediaController: MediaController? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            MyApplicationTheme {
                // A surface container using the 'background' color from the theme
                Surface(
                    modifier = Modifier.fillMaxSize(),
                    color = MaterialTheme.colorScheme.background
                ) {
                    Column {
                        Button(onClick = {
                            mediaController?.let {
                                it.setMediaItem(
                                    MediaItem.Builder()
                                        .setUri("https://demo.unified-streaming.com/k8s/features/stable/video/tears-of-steel/tears-of-steel.ism/.m3u8")
                                        .setMediaId("id")
                                        .setMediaMetadata(
                                            MediaMetadata.Builder()
                                                .setTitle("Test title")
                                                .setArtist("Test artist")
                                                .setArtworkUri("https://images.unsplash.com/photo-1679663877752-c00ad7f1c5c5?ixlib=rb-4.0.3&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=2940&q=80".toUri())
                                                .build()
                                        )
                                        .build()
                                )
                                it.prepare()
                                it.play()
                            }
                        }) {
                            Text(text = "Play by service")
                        }

                        val player = remember {
                            ExoPlayer.Builder(this@MainActivity)
                                .setMediaSourceFactory(
                                    DefaultMediaSourceFactory(this@MainActivity)
                                        .setDataSourceFactory(
                                            DefaultDataSource.Factory(
                                                this@MainActivity,
                                                OkHttpDataSource.Factory(OkHttpClient.Builder().build())
                                            )
                                        )
                                )
                                .build()
                                .apply {
                                    addAnalyticsListener(EventLogger())
                                }
                        }
                        Button(onClick = {
                            player.let {
                                it.setMediaItem(
                                    MediaItem.Builder()
                                        .setUri("https://demo.unified-streaming.com/k8s/features/stable/video/tears-of-steel/tears-of-steel.ism/.m3u8")
                                        .setMediaId("id")
                                        .setMediaMetadata(
                                            MediaMetadata.Builder()
                                                .setTitle("Test title")
                                                .setArtist("Test artist")
                                                .setArtworkUri("https://images.unsplash.com/photo-1679663877752-c00ad7f1c5c5?ixlib=rb-4.0.3&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=2940&q=80".toUri())
                                                .build()
                                        )
                                        .build()
                                )
                                it.prepare()
                                it.play()
                            }
                        }) {
                            Text(text = "Play locally")
                        }
                    }
                }
            }
        }
    }

    override fun onStart() {
        super.onStart()
        val sessionToken = SessionToken(this@MainActivity, ComponentName(this@MainActivity, PlaybackService::class.java))
        val controllerFuture = MediaController.Builder(this, sessionToken).buildAsync()
        controllerFuture.addListener(
            { mediaController = controllerFuture.get() },
            MoreExecutors.directExecutor()
        )
    }

    override fun onStop() {
        mediaController?.release()
        mediaController = null
        super.onStop()
    }
}